(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('rxjs'), require('@angular/platform-browser'), require('@angular/animations'), require('rxjs/operators'), require('@angular/common')) :
    typeof define === 'function' && define.amd ? define('ngx-notifier', ['exports', '@angular/core', 'rxjs', '@angular/platform-browser', '@angular/animations', 'rxjs/operators', '@angular/common'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['ngx-notifier'] = {}, global.ng.core, global.rxjs, global.ng.platformBrowser, global.ng.animations, global.rxjs.operators, global.ng.common));
}(this, (function (exports, core, rxjs, platformBrowser, animations, operators, common) { 'use strict';

    /** Notification Class */
    var Notification = /** @class */ (function () {
        /**
         * Constructor For Notification
         *
         * @param message message to be shown
         * @param style bootstrap background colors
         * @param duration timeout for notification
         */
        function Notification(message, style, duration) {
            this.id = '_' + Math.random().toString(36).substr(2, 9); // generate a random number
            this.message = message;
            this.style = style || 'info';
            this.duration = duration;
        }
        return Notification;
    }());

    /** Notification Service, recieves notifications from user and interacts with components */
    var NgxNotifierService = /** @class */ (function () {
        function NgxNotifierService() {
            /** notification which can be subscribed on new messages */
            this.notification = new rxjs.Subject();
            /** clear all toast notifications */
            this.clearToasts = new rxjs.Subject();
            /** clear last toast notification */
            this.clearLastToast = new rxjs.Subject();
        }
        /** pushes a new notification */
        NgxNotifierService.prototype.createToast = function (message, style, duration) {
            this.notification.next(new Notification(message, style, duration));
        };
        /** clear all toast notifications */
        NgxNotifierService.prototype.clear = function () {
            this.clearToasts.next();
        };
        /** clear last toast notification */
        NgxNotifierService.prototype.clearLast = function () {
            this.clearLastToast.next();
        };
        return NgxNotifierService;
    }());
    NgxNotifierService.decorators = [
        { type: core.Injectable }
    ];

    /**
     * Notifier compoent, which holds all the notifications can be accessed via `ngx-notifier` selector
     */
    var NgxNotifierComponent = /** @class */ (function () {
        /**
         * NgxNotifierComponent Constructor
         *
         * @param ngxNotifierService subscribe to get values form notifier service
         */
        function NgxNotifierComponent(ngxNotifierService, domSanitizer) {
            var _this = this;
            this.ngxNotifierService = ngxNotifierService;
            this.domSanitizer = domSanitizer;
            this.componentDestroyed$ = new rxjs.Subject();
            /** whether to allow duplicate messages or not */
            this.allowDuplicates = true;
            /** allow HTML in notification */
            this.allowHTML = false;
            /** default duration for dismissing notifications (60s/1minute) */
            this.duration = 60000;
            /** weather to enable or disable animations */
            this.disableAnimations = false;
            /** click to dismiss a notification */
            this.dismissOnClick = false;
            /** whether to insert on top or at bottom */
            this.insertOnTop = true;
            /** Maximum number of notifications to keep */
            this.max = 5;
            /** array of notifications */
            this.notifications = [];
            this.ngxNotifierService.notification.pipe(operators.takeUntil(this.componentDestroyed$)).subscribe(function (notification) { _this.updateNotifications(notification); });
            this.ngxNotifierService.clearToasts.pipe(operators.takeUntil(this.componentDestroyed$)).subscribe(function () { _this.notifications = []; });
            this.ngxNotifierService.clearLastToast.pipe(operators.takeUntil(this.componentDestroyed$)).subscribe(function () { _this.clearLastToast(); });
        }
        /**
         * updates notification into the array i.e., Which is the display
         *
         * @param notification notification element
         */
        NgxNotifierComponent.prototype.updateNotifications = function (notification) {
            var _this = this;
            // checks whether the message is alrady present in notifications
            var index = this.notifications.map(function (e) { return e.message; }).indexOf(notification.message);
            if (!this.allowDuplicates) {
                if (index !== -1) {
                    return;
                }
            }
            // save the last inserted Id
            this.lastInsertedNotificationId = notification.id;
            // sanitize html if enableHTML is set to true
            var sanitizedMessage;
            if (notification.message && this.allowHTML) {
                sanitizedMessage = this.domSanitizer.sanitize(core.SecurityContext.HTML, notification.message);
            }
            // set sanitized output to notification message
            notification.message = sanitizedMessage || notification.message;
            // insert notification in the first position of the array
            if (this.insertOnTop) {
                this.notifications.unshift(notification);
            }
            else {
                this.notifications.push(notification);
            }
            /**
             * remove the last inserted element if max has
             * pop or shift based on `insertOnTop`
             */
            if (this.notifications.length > this.max) {
                if (this.insertOnTop) {
                    this.notifications.pop();
                }
                else {
                    this.notifications.shift();
                }
            }
            // clear notification in given time
            setTimeout(function () {
                _this.notifications.splice(index, 1);
            }, notification.duration || this.duration);
            return;
        };
        /**
         * remove the element from the array based on index
         *
         * @param index position of the element
         */
        NgxNotifierComponent.prototype.removeNotification = function (index) {
            if (index !== undefined || index !== null) {
                this.notifications.splice(index, 1);
            }
            return;
        };
        /**
         * click event when toast is cleared
         *
         * @param index position of the element
         */
        NgxNotifierComponent.prototype.onToastClick = function (index) {
            if (this.dismissOnClick) {
                this.removeNotification(index);
            }
            return;
        };
        /** clear last inserted toast notification */
        NgxNotifierComponent.prototype.clearLastToast = function () {
            var index = this.notifications.map(function (e) { return e.id; }).indexOf(this.lastInsertedNotificationId);
            if (this.notifications.length !== 0 && index !== -1) {
                this.notifications.splice(index, 1);
            }
            return;
        };
        /** stop subscription when component is destroyed */
        NgxNotifierComponent.prototype.ngOnDestroy = function () {
            this.componentDestroyed$.next();
            this.componentDestroyed$.complete();
        };
        return NgxNotifierComponent;
    }());
    NgxNotifierComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ngx-notifier',
                    template: "<div class=\"ngx-notifier\" *ngIf=\"notifications?.length !== 0\" [ngClass]=\"className\" [@animateToasts] [@.disabled]=\"disableAnimations\">\n  <div [ngClass]=\"{'pointer': dismissOnClick}\">\n    <div class=\"ngx-n-notification alert\" role=\"alert\" *ngFor=\"let notification of notifications; let i = index\"\n      [ngClass]=\"'alert-'+ notification.style\" (click)=\"onToastClick(i)\" [@animateToasts]>\n      <button type=\"button\" class=\"close\" aria-label=\"Close\" (click)=\"removeNotification(i)\">\n        <span aria-hidden=\"true\">&times;</span>\n      </button>\n      <p *ngIf=\"allowHTML\" [innerHTML]=\"notification.message\"> </p>\n      <p *ngIf=\"!allowHTML\">{{ notification.message }} </p>\n    </div>\n  </div>\n</div>\n",
                    animations: [
                        animations.trigger('animateToasts', [
                            animations.state('void', animations.style({ opacity: 0 })),
                            animations.transition(':enter, :leave', [
                                animations.animate('0.3s ease')
                            ])
                        ])
                    ],
                    styles: [".chevron:before{border-style:solid;border-width:.15rem .15rem 0 0;content:\"\";display:inline-block;height:.45em;position:relative;transform:rotate(-45deg);width:.45em}.chevron.right:before{left:0;transform:rotate(45deg)}.chevron.bottom:before{top:0;transform:rotate(135deg)}.chevron.left:before{left:.25em;transform:rotate(-135deg)}.ngx-notifier{bottom:1rem;max-width:25rem;min-width:25rem;position:fixed;right:1rem}.ngx-notifier .pointer{cursor:pointer}.ngx-notifier .ngx-n-notification{border-radius:4px;margin-top:.5rem;padding:.5rem}.ngx-notifier .ngx-n-notification p{margin:0}.ngx-notifier .ngx-n-notification .close{font-size:1.2rem}.ngx-notifier .ngx-n-notification .close:focus{outline:none}@media only screen and (max-width:420px){.ngx-notifier{max-width:20rem;min-width:20rem}}"]
                },] }
    ];
    NgxNotifierComponent.ctorParameters = function () { return [
        { type: NgxNotifierService },
        { type: platformBrowser.DomSanitizer }
    ]; };
    NgxNotifierComponent.propDecorators = {
        allowDuplicates: [{ type: core.Input }],
        allowHTML: [{ type: core.Input }],
        className: [{ type: core.Input }],
        duration: [{ type: core.Input }],
        disableAnimations: [{ type: core.Input }],
        dismissOnClick: [{ type: core.Input }],
        insertOnTop: [{ type: core.Input }],
        max: [{ type: core.Input }]
    };

    var NgxNotifierModule = /** @class */ (function () {
        function NgxNotifierModule() {
        }
        return NgxNotifierModule;
    }());
    NgxNotifierModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [common.CommonModule],
                    declarations: [NgxNotifierComponent],
                    providers: [NgxNotifierService],
                    exports: [NgxNotifierComponent]
                },] }
    ];

    /*
     * Public API Surface of ngx-notifier
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.NgxNotifierComponent = NgxNotifierComponent;
    exports.NgxNotifierModule = NgxNotifierModule;
    exports.NgxNotifierService = NgxNotifierService;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-notifier.umd.js.map
